@@ -22,33 +22,42 @@
 #'
 #' dat <- addDataDF(dat, RT = list("Comp_comp"   = c(500, 150, 100),
 #'                                 "Comp_incomp" = c(520, 150, 100)))
-#' printTable(dat, digits = 1) # latex formatted
+#' printTable(dat, digits = c(0, 2)) # latex formatted
+#' printTable(dat, digits = 0)       # latex formatted
 #'
 #' dat$VP <- as.factor(dat$VP)
 #' aovRT <- ezANOVA(dat, dv=.(RT), wid = .(VP), within = .(Comp),
 #'                  return_aov = TRUE, detailed = TRUE)
 #' aovRT <- aovTable(aovRT)
-#' printTable(aovRT$ANOVA, digits = c(0, 0, 2, 2, 2)) # latex formatted
+#' printTable(aovRT$ANOVA) # latex formatted
+#' printTable(aovRT$ANOVA, digits = c(0,2,2,2)) # latex formatted
+#'
 #'
 #' @export
 printTable <- function(obj, caption = "DF", digits=3, onlyContents=FALSE,
                        formatStatsSymbols = TRUE) {
 
-  # typical symbols in ANOVA table
-  if (formatStatsSymbols) {
-    names(obj) <- sub("\\<p\\>",   "\\\\textit{p}",   names(obj))
-    names(obj) <- sub("\\<F\\>",   "\\\\textit{F}",   names(obj))
-    names(obj) <- sub("\\<pes\\>", "$\\\\eta_{p}^2$", names(obj))
-    names(obj) <- sub("\\<ges\\>", "$\\\\eta_{G}^2$", names(obj))
-    names(obj) <- sub("\\<eps\\>", "$\\\\epsilon$",   names(obj))
-  }
+    # typical symbols in ANOVA table
+    if (formatStatsSymbols) {
+        names(obj) <- sub("\\<p\\>",   "\\\\textit{p}",   names(obj))
+        names(obj) <- sub("\\<F\\>",   "\\\\textit{F}",   names(obj))
+        names(obj) <- sub("\\<pes\\>", "$\\\\eta_{p}^2$", names(obj))
+        names(obj) <- sub("\\<ges\\>", "$\\\\eta_{G}^2$", names(obj))
+        names(obj) <- sub("\\<eps\\>", "$\\\\epsilon$",   names(obj))
+    }
 
     if (length(digits) != 1) {
         if(length(digits) != ncol(obj)){
-            numeric_cols <- which(unlist(lapply(obj, is.numeric)))
-            if(length(digits) != length(numeric_cols)){
+            # find numeric columns
+            numeric_cols <- as.vector(which(unlist(lapply(obj, is.numeric))))
+            if (length(numeric_cols) == 0) {
+                digits = 0
+                message("obj does not contain numeric columns! No additional formatting applied.", immediate = TRUE)
+            }
+            else if(length(digits) != length(numeric_cols)){
                 stop("Number of digits does not equal number of numeric columns!")
             } else {
+                # make digits length required by xtable command
                 tmp = rep(0, ncol(obj))
                 tmp[numeric_cols] <- digits
                 digits <- c(0, tmp)
@@ -56,16 +65,18 @@ printTable <- function(obj, caption = "DF", digits=3, onlyContents=FALSE,
         }
     }
 
-  tab <- xtable::xtable(obj, caption = caption, digits = digits)
+    tab <- xtable::xtable(obj, caption = caption, digits=digits)
+
+    print(tab,
+          table.placement = "H",
+          caption.placement = "top",
+          include.rownames = FALSE,
+          floating = FALSE,
+          tabular.environment = "longtable",
+          only.contents = onlyContents,
+          hline.after = c(-1, 0),
+          sanitize.text.function = function(x){x})
 
-  print(tab,
-        table.placement = "H",
-        caption.placement = "top",
-        include.rownames = FALSE,
-        floating = FALSE,
-        tabular.environment = "longtable",
-        only.contents = onlyContents,
-        sanitize.text.function = function(x){x})
 }
 
 
@@ -93,14 +104,14 @@ printTable <- function(obj, caption = "DF", digits=3, onlyContents=FALSE,
 mathString <- function(str1, str2, operation = "-",
                        numDigits = 0, unit = "ms") {
 
-  extractNum <- function(x){
-    return(as.numeric(regmatches(x, gregexpr("[[:digit:]]+\\.*[[:digit:]]*", x))))
-  }
+    extractNum <- function(x){
+        return(as.numeric(regmatches(x, gregexpr("[[:digit:]]+\\.*[[:digit:]]*", x))))
+    }
 
-  nums <- lapply(list(str1, str2), extractNum)
-  result <- do.call(operation, nums)
+    nums <- lapply(list(str1, str2), extractNum)
+    result <- do.call(operation, nums)
 
-  return(numValueString(result, numDigits, unit))
+    return(numValueString(result, numDigits, unit))
 
 }
 
@@ -130,18 +141,18 @@ mathString <- function(str1, str2, operation = "-",
 #' @export
 numValueString <- function(value, numDigits = 2, unit = "") {
 
-  value <- format(round(value, numDigits), nsmall = numDigits)
-  if (unit %in% c("mv", "mV")) {
-    return(paste0(value, " $\\mu$V"))
-  } else if (unit == "ms") {
-    return(paste0(value, " ms"))
-  } else if (unit == "%") {
-    return(paste0(value, " \\%"))
-  } else if (unit == "") {
-    return(paste0(value))
-  } else {
-    stop("Unit not recognized! Unit should be \"mv\", \"mV\", \"ms\" or \"%\".")
-  }
+    value <- format(round(value, numDigits), nsmall = numDigits)
+    if (unit %in% c("mv", "mV")) {
+        return(paste0(value, " $\\mu$V"))
+    } else if (unit == "ms") {
+        return(paste0(value, " ms"))
+    } else if (unit == "%") {
+        return(paste0(value, " \\%"))
+    } else if (unit == "") {
+        return(paste0(value))
+    } else {
+        stop("Unit not recognized! Unit should be \"mv\", \"mV\", \"ms\" or \"%\".")
+    }
 
 }
 
@@ -151,43 +162,40 @@ numValueString <- function(value, numDigits = 2, unit = "") {
 #'
 #' @description Returns Latex formatted string from a p-value required for R/knitr integration.
 #' For example, \emph{p} = 0.11 or \emph{p} < 0.01
-#' Returns values to 2 sig decimal places if p-value >= 0.05.
+#' Returns values to 3 sig decimal places or < .001
 #'
 #' @param pVal p-value between 0 and 1
-#' @param nsmall Number of small digits to round to
 #'
 #' @return character
 #'
 #' @examples
 #' # Example 1:
-#' pString <- pValueString(0.67)
+#' pString <- pValueString(0.670)
 #'
 #' # Example 2:
-#' pString <- pValueString(0.1234, 3)
+#' pString <- pValueString(0.1234)
 #'
 #' # Example 3:
 #' pString <- pValueString("0.03")
 #'
 #' @export
-pValueString <- function(pVal, nsmall = 2){
+pValueString <- function(pVal){
 
-  if (is.character(pVal)) {
-     pVal <- as.numeric(pVal)
-     if (is.na(pVal)) {
-      stop("Can't convert string to number!")
-     }
-  }
+    if (is.character(pVal)) {
+        pVal <- as.numeric(pVal)
+        if (is.na(pVal)) {
+            stop("Can't convert string to number!")
+        }
+    }
 
-  if (pVal >= 0.01) {
-    string <- paste0("\\emph{p} = ", format(round(pVal, nsmall), nsmall = nsmall))
-    string <- gsub("0\\.", ".", string)
-  } else if (pVal >= 0.001 & pVal < 0.01) {
-    string <- paste0("\\emph{p}", " < .01")
-  } else if (pVal < 0.001) {
-    string <- paste0("\\emph{p}", " < .001")
-  }
+    if (pVal >= 0.001) {
+        string <- paste0("\\emph{p} = ", sprintf("%.3f", pVal))
+        string <- gsub("0\\.", ".", string)
+    } else if (pVal < 0.001) {
+        string <- paste0("\\emph{p}", " < .001")
+    }
 
-  return(string)
+    return(string)
 
 }
 
@@ -210,15 +218,15 @@ pValueString <- function(pVal, nsmall = 2){
 #' @export
 pValueSummary <- function(pVal) {
 
-  if (!is.numeric(pVal)) {
-     stop("Input contains a non-number!")
-  }
+    if (!is.numeric(pVal)) {
+        stop("Input contains a non-number!")
+    }
 
-  psum <- ifelse(pVal < 0.001, "***",
-                 ifelse(pVal < 0.01, "**",
-                       ifelse(pVal <= 0.05, "*", "")))
+    psum <- ifelse(pVal < 0.001, "***",
+                   ifelse(pVal < 0.01, "**",
+                          ifelse(pVal <= 0.05, "*", "")))
 
-  return(psum)
+    return(psum)
 
 }
 
@@ -241,22 +249,22 @@ requiredPackages <- function(packages,
                              lib = .libPaths()[1],
                              repos = "http://cran.us.r-project.org"){
 
-  isPackageInstalled <- packages %in% rownames(utils::installed.packages())
-
-  if (any(!isPackageInstalled) & installPackages) {
-    isPackageAvailable <- packages %in% rownames(utils::available.packages(repos = repos))
-    if (any(!isPackageAvailable)) {
-      stop(paste0("Package ", packages[!isPackageAvailable], " not available!"))
-    }
-    utils::install.packages(packages[!isPackageInstalled],
-                            lib = lib,
-                            repos = repos,
-                            dependencies = TRUE)
     isPackageInstalled <- packages %in% rownames(utils::installed.packages())
-  } else if (any(!isPackageInstalled)) {
-    stop(paste0("Package ", packages[!isPackageInstalled], " not installed!"))
-  }
 
-  lapply(packages[isPackageInstalled], library, character.only = TRUE)
+    if (any(!isPackageInstalled) & installPackages) {
+        isPackageAvailable <- packages %in% rownames(utils::available.packages(repos = repos))
+        if (any(!isPackageAvailable)) {
+            stop(paste0("Package ", packages[!isPackageAvailable], " not available!"))
+        }
+        utils::install.packages(packages[!isPackageInstalled],
+                                lib = lib,
+                                repos = repos,
+                                dependencies = TRUE)
+        isPackageInstalled <- packages %in% rownames(utils::installed.packages())
+    } else if (any(!isPackageInstalled)) {
+        stop(paste0("Package ", packages[!isPackageInstalled], " not installed!"))
+    }
+
+    lapply(packages[isPackageInstalled], library, character.only = TRUE)
 
 }
